<?php

require __DIR__ . "/vendor/autoload.php";
require __DIR__ . "/vendor/zeedhi/framework/bootstrap.php";
require __DIR__ . "/vendor/teknisa/libraries/scripts/bootstrap.php";

$instanceManager = \Zeedhi\Framework\DependencyInjection\InstanceManager::getInstance();

$routes = array();
$routes[] = __DIR__ . '/vendor/teknisa/libraries/libRoutes.json';
$routes[] = __DIR__ . '/vendor/zeedhi/preferences/routes.json';
$routes[] = __DIR__ . '/routes.json';

$instanceManager->loadFromFile('../config/db.xml');
$instanceManager->loadFromFile('../config/general.xml');
$instanceManager->loadFromFile('../config/report.xml');
$instanceManager->loadFromFile('../config/parameters.xml');
$instanceManager->loadFromFile('../config/environment.xml');
$instanceManager->loadFromFile('../vendor/zeedhi/preferences/services.xml');
$instanceManager->loadFromFile(__DIR__ . "/config/fileUploader.xml");

$container = $instanceManager->getContainer();

if ($container->hasParameter('use_zhu_acl') && $container->getParameter('use_zhu_acl') == 'true'){
    $acl = __DIR__ . '/config/acl.xml';

    if(realpath($acl)) {
        $instanceManager->loadFromFile($acl);
    }
    require __DIR__ . "/vendor/zeedhi/zhuaclbackend/service/bootstrap.php";
    $routes[] = __DIR__ . "/vendor/zeedhi/zhuaclbackend/config/routes.json";
}

if ($container->hasParameter('use_zhu_update') && $container->getParameter('use_zhu_update') == 'true'){
    $zhu = __DIR__ . '/../modules/acl/backend/config/zhuUpdate.xml';

    if(realpath($zhu)){
        $instanceManager->loadFromFile($zhu);
    }
}

if ($container->hasParameter('use_zhu_log') && $container->getParameter('use_zhu_log') == 'true') {
    $zhuDateFormat = $container->getParameter('zhuLogDateFormat');
    $ignoredRoutes = $container->hasParameter('logIgnoredRoutes') ? $container->getParameter('logIgnoredRoutes') : [];

    require __DIR__ . "/vendor/zeedhi/zhulog/config/bootstrap.php";
    $routes[] = __DIR__."/vendor/zeedhi/zhulog/config/routes.json";

    $log = __DIR__.'/../modules/acl/backend/config/log.xml';
    if(realpath($log)){
        $instanceManager->loadFromFile($log);
    }

    $libLog = __DIR__.'/vendor/teknisa/libraries/zhuLog.xml';
    if(realpath($libLog)){
        $instanceManager->loadFromFile($libLog);
    }

    $container->setParameter('logIgnoredRoutes', $ignoredRoutes);
    $container->setParameter('zhuLogDateFormat', $zhuDateFormat);
}

$mapping = file_get_contents(__DIR__ . "/config/servicesMapping.json");
$mapping = json_decode($mapping, true);

function getFilePathExtension($path) {
	return substr(strrchr($path, '.'), 1);
}

foreach ($mapping as $path) {
	$ext = getFilePathExtension($path);
	if($ext === 'xml')
		$instanceManager->loadFromFile(__DIR__ . $path);
	if($ext === 'json')
		$routes[] = __DIR__ . $path;
}

$instanceManager->registerService('routeParser', new \Zeedhi\Framework\Routing\Parsers\JSONFormat($routes));

$instanceManager->compile();

